@@ -17,13 +17,16 @@ import escapetheforest.tiles
 # Im thinking its time to introduce an NPC that its possible to hold a conversation with! An old man in a hut? 
 # A troll, at first appearing to be a stone?
 
-import escapetheforest.world
-from escapetheforest.player import Player
+import escapetheforest.world as world
+import escapetheforest.player as player
+#from escapetheforest.player import Player
+import os
+print(os.getcwd())
 
 def play():
 
     world.load_tiles()
-    pc = Player()
+    pc = player.Player()
     #The below line prints out all the attributes of the player
     #print(pc.__dict__)
     print("\n","====================THE FOREST ESCAPE========================")
@@ -70,12 +73,15 @@ def play():
            
 
 if __name__ == "__main__":
+    import sys
+    import os
+    sys.path.append(os.path.dirname(os.path.realpath(__file__)))
     import escapetheforest.items as items
     import escapetheforest.world as world
     import escapetheforest.enemies as enemies
     import escapetheforest.tiles as tiles
     import escapetheforest.actions as actions
     import escapetheforest.player as player
-    from player import Player
+    #from player import Player
 
     play()
