@@ -1,8 +1,11 @@
+"""This is the actual world """
 
 import escapetheforest.tiles as tiles
-
-"""This is the actual world """
 import random
+import os
+
+THIS_FOLDER = os.path.dirname(os.path.abspath(__file__))
+map_file = os.path.join(THIS_FOLDER, 'map.txt')
 
 _world = {}
 starting_position = (0, 0)
@@ -12,12 +15,14 @@ starting_position = (0, 0)
 
 def load_tiles():
     """Parses a file that describes the world space into the _world object"""
-    with open('resources/map.txt', 'r') as f:
-        rows = f.readlines()
-        row=[]
+    with open(map_file, "r") as f:
+        rows = f.readlines()    #This is a variable that contains a number of rows,
+                                # where each row is just a string containing all the information on each row in the "map.txt".
+                                #This means that each row contains tile names as well as codes indicating tabs and new lines.
+  #      row=[]
 
-        # the following lines takes each row of the map.txt file and appends them to a long list. Then it shuffles the list randomly and then it
-        # creates a new list with all the tiles randomly shuffled.
+# the following lines takes each row of the map.txt file and appends them to a long list. Then it shuffles the list randomly and then it
+# creates a new list with all the tiles randomly shuffled.
 
   #      for i in range(len(rows)):
   #          row.extend(rows[i].replace('\n','').split('\t'))
@@ -30,17 +35,25 @@ def load_tiles():
   #              row2.append('\t'.join(row[val:val+4])+'\n')
   #              #print(row2)
   #              val+=4
-
   #  rows=row2
-    x_max = len(rows[0].split('\t')) # Assumes all rows contain the same number of tabs
 
-    for y in range(len(rows)):
-        cols = rows[y].split('\t')
+    print(rows)
+    print(type(rows))
+    x_max = len(rows[0].split('\t')) # This creates a variable x_max that is a number which is based on the length of the first row in the "rows" variable when splitting it on "/t/".
+                                        ## This assumes all rows contain the same number of tabs.
 
-        for x in range(x_max):
-            tile_name = cols[x].replace('\n', '') # Windows users may need to replace '\r\n'
+    for y in range(len(rows)):  # For the whole length of the rows variable:
+        cols = rows[y].split('\t')  #Split each row into a number of columns, by using the "/t" or tab command.
+        print(cols)
+
+        for x in range(x_max):  # For the length of each row:
+            tile_name = cols[x].replace('\n', '') # Create a new variable "tile_name" that contains the tilename in each column positon,
+                                                    # where each newline indication "/n/" has been replaced with nothing ''.
+                                                    #This basically cleans out so that only the clean tilename will be the current value of "tile_name" variable
+                                                    # Windows users may need to replace '\r\n'
 
             #This just says that if the tile_name is startingroom, that should be our starting position.
+            # The Starting_position variable is global so it can replace the value of the variable established in the beginning of this module.
             if tile_name == 'startingRoom':
                 global starting_position
                 starting_position = (x, y)
